Types
=====

Events, items, inputs, and options payloads.

When to use this page
---------------------

- You want to inspect event/item dataclasses emitted by streaming.
- You want the exact option keys available in ``CodexOptions``, ``ThreadOptions``, and ``TurnOptions``.

.. automodule:: acodex.types.input
   :members:
   :member-order: bysource

.. automodule:: acodex.types.events
   :members:
   :member-order: bysource

.. automodule:: acodex.types.items
   :members:
   :member-order: bysource

.. automodule:: acodex.types.codex_options
   :members:
   :member-order: bysource

.. automodule:: acodex.types.thread_options
   :members:
   :member-order: bysource

.. automodule:: acodex.types.turn_options
   :members:
   :member-order: bysource
